@@ -3,7 +3,6 @@ from __future__ import absolute_import, unicode_literals
 from collections import defaultdict
 from datetime import datetime, timedelta
 
-from django.db import transaction
 from django.conf import settings
 
 from celery import states
@@ -77,7 +76,7 @@ class Camera(Polaroid):
 
     def handle_task(self, uuid_task, worker=None):
         """Handle snapshotted event."""
-        (uuid, task) = uuid_task
+        uuid, task = uuid_task
         if task.worker and task.worker.hostname:
             worker = self.handle_worker(
                 (task.worker.hostname, task.worker),
@@ -130,15 +129,10 @@ class Camera(Polaroid):
         return obj
 
     def on_shutter(self, state, commit_every=100):
-        if not state.event_count:
-            transaction.commit()
-            return
 
         def _handle_tasks():
             for i, task in enumerate(state.tasks.items()):
                 self.handle_task(task)
-                if not i % commit_every:
-                    transaction.commit()
 
         for worker in state.workers.items():
             self.handle_worker(worker)
