@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from datetime import timedelta
 
@@ -8,6 +8,7 @@ from celery.result import AsyncResult
 from celery.task import PeriodicTask
 from celery.utils import gen_unique_id
 
+from djcelery.app import app
 from djcelery.backends.database import DatabaseBackend
 from djcelery.utils import now
 from djcelery.tests.utils import unittest
@@ -30,7 +31,7 @@ class MyPeriodicTask(PeriodicTask):
 class TestDatabaseBackend(unittest.TestCase):
 
     def test_backend(self):
-        b = DatabaseBackend()
+        b = DatabaseBackend(app=app)
         tid = gen_unique_id()
 
         self.assertEqual(b.get_status(tid), states.PENDING)
@@ -51,14 +52,14 @@ class TestDatabaseBackend(unittest.TestCase):
         tid3 = gen_unique_id()
         try:
             raise KeyError('foo')
-        except KeyError, exception:
+        except KeyError as exception:
             pass
         b.mark_as_failure(tid3, exception)
         self.assertEqual(b.get_status(tid3), states.FAILURE)
         self.assertIsInstance(b.get_result(tid3), KeyError)
 
     def test_forget(self):
-        b = DatabaseBackend()
+        b = DatabaseBackend(app=app)
         tid = gen_unique_id()
         b.mark_as_done(tid, {'foo': 'bar'})
         x = AsyncResult(tid)
@@ -67,7 +68,7 @@ class TestDatabaseBackend(unittest.TestCase):
         self.assertIsNone(x.result)
 
     def test_group_store(self):
-        b = DatabaseBackend()
+        b = DatabaseBackend(app=app)
         tid = gen_unique_id()
 
         self.assertIsNone(b.restore_group(tid))
@@ -82,7 +83,7 @@ class TestDatabaseBackend(unittest.TestCase):
         self.assertIsNone(b.restore_group(tid))
 
     def test_cleanup(self):
-        b = DatabaseBackend()
+        b = DatabaseBackend(app=app)
         b.TaskModel._default_manager.all().delete()
         ids = [gen_unique_id() for _ in xrange(3)]
         for i, res in enumerate((16, 32, 64)):
